Imports Syncfusion.Windows.Forms.Grid

Public Class Form1

    Sub New()

        ' This call is required by the Windows Form Designer.
        InitializeComponent()

        ' Add any initialization after the InitializeComponent() call.
        ResetGridStyles()

    End Sub

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

        With Me.GridControl1

            .BeginUpdate()

            Dim dt As Data.DataTable = GetSampleData

            'commit changes first so that we're starting from a "no edits" state
            dt.AcceptChanges()

            'clear rows and cols first
            .RowCount = 0
            .ColCount = 0

            'number of frozen cols will vary (is fixed for this sample)
            Dim frozenCols As Integer = 3

            'HeaderCount is 0-based index of last header row
            .Cols.HeaderCount = -1 'don't use the row header style
            .Cols.FrozenCount = frozenCols - 1
            .RowCount = dt.Rows.Count + .Rows.HeaderCount
            .ColCount = dt.Columns.Count - 1

            'set column headers
            'SetColumnCaptions()

            'bind the FlexGrid to the report data
            .PopulateValues(GridRangeInfo.Cells(.Rows.HeaderCount + 1, 0, .RowCount, .ColCount), dt)

            'apply some row formats
            For row As Integer = .Rows.HeaderCount + 1 To 5
                .RowStyles(row) = .BaseStylesMap("Subtotal" & row).StyleInfo
            Next

            ApplyFrozenColStyles()

            'autosize columns
            .ColWidths.ResizeToFit(GridRangeInfo.Table, GridResizeToFitOptions.IncludeCellsWithinCoveredRange Or GridResizeToFitOptions.IncludeHeaders)

            .EndUpdate()

        End With

    End Sub

    ''' <summary>
    ''' Applies the FrozenCol style to all frozen columns, merging with any existing styles
    ''' set on individual rows
    ''' </summary>
    Public Sub ApplyFrozenColStyles()

        Dim frozenStyle As GridStyleInfo = Me.GridControl1.BaseStylesMap("FrozenCols").StyleInfo

        Me.GridControl1.ChangeCells(GridRangeInfo.Cols(0, Me.GridControl1.Cols.FrozenCount), frozenStyle)

    End Sub

    ''' <summary>
    ''' Resets the FlexGrid's subtotal styles to the standard ones used in IFP
    ''' </summary>
    Private Sub ResetGridStyles()

        Try
            'standard style - black border right, non-editable cells 
            With Me.GridControl1.BaseStylesMap("Standard").StyleInfo
                .Borders.Right = New GridBorder(GridBorderStyle.Solid, Color.Black, GridBorderWeight.Thin)
                .CellType = "Static"
            End With

            'FrozenCols style
            Dim frozenColsStyle As New GridStyleInfo

            With frozenColsStyle
                .BackColor = Color.AliceBlue
                .HorizontalAlignment = GridHorizontalAlignment.Left
                .ResetTextMargins()
            End With

            ResetStyle("FrozenCols", frozenColsStyle)

            Dim baseSubTotalStyle As New GridStyleInfo
            Dim subTotalStyle As GridStyleInfo

            'set default properties for all subtotal styles
            With baseSubTotalStyle
                .Font.Facename = "Arial"
                .Font.Size = 8.25
                .Font.Bold = True
                .Borders.Top = New GridBorder(GridBorderStyle.Solid, Color.Black, GridBorderWeight.Thin)
                .Borders.Bottom = New GridBorder(GridBorderStyle.Solid, Color.Black, GridBorderWeight.Thin)
            End With

            'now add the individual styles
            subTotalStyle = New GridStyleInfo(baseSubTotalStyle)
            subTotalStyle.BackColor = Color.Gray
            subTotalStyle.TextColor = Color.White
            ResetStyle("Subtotal0", subTotalStyle)

            subTotalStyle = New GridStyleInfo(baseSubTotalStyle)
            subTotalStyle.BackColor = Color.DarkGray
            subTotalStyle.TextColor = Color.Black
            ResetStyle("Subtotal1", subTotalStyle)

            subTotalStyle = New GridStyleInfo(baseSubTotalStyle)
            subTotalStyle.BackColor = Color.Silver
            subTotalStyle.TextColor = Color.Black
            ResetStyle("Subtotal2", subTotalStyle)

            subTotalStyle = New GridStyleInfo(baseSubTotalStyle)
            subTotalStyle.BackColor = Color.LightGray
            subTotalStyle.TextColor = Color.Black
            ResetStyle("Subtotal3", subTotalStyle)

            subTotalStyle = New GridStyleInfo(baseSubTotalStyle)
            subTotalStyle.BackColor = Color.Gainsboro
            subTotalStyle.TextColor = Color.Black
            ResetStyle("Subtotal4", subTotalStyle)

            subTotalStyle = New GridStyleInfo(baseSubTotalStyle)
            subTotalStyle.BackColor = Color.WhiteSmoke
            subTotalStyle.TextColor = Color.Black
            ResetStyle("Subtotal5", subTotalStyle)

        Catch
            Debug.Assert(False, "Unable to reset subtotal styles.")
        End Try

    End Sub

    ''' <summary>
    ''' Resets an individual style to the information in the style string
    ''' </summary>
    Private Sub ResetStyle(ByVal styleName As String, ByVal style As GridStyleInfo)

        Dim baseStyle As New GridBaseStyle(styleName, False, style)
        Me.GridControl1.BaseStylesMap.Add(baseStyle)

    End Sub

    Private Function GetSampleData() As Data.DataTable

        Dim dt As New DataTable

        For i As Integer = 1 To 10
            dt.Columns.Add(New DataColumn("Col " & i, GetType(String)))
        Next

        Dim dr As DataRow

        For row As Integer = 0 To 10

            dr = dt.NewRow

            For col As Integer = 1 To 10
                dr(col - 1) = String.Format("Row {0}, Col {1}", row, col)
            Next

            dt.Rows.Add(dr)
        Next

        Return dt

    End Function
End Class
